searchData={"items":[{"type":"module","title":"Rsync","doc":"Wrapper for the rsync command, reporting percent completion\n\nThe main entry point is `sync/3`, which starts a linked GenServer to monitor\nthe transfer.  The simplest usage would be to simply wait for the subprocess\nto complete successfully.  Progress can be monitored by calling\n`get_progress/1` or the caller can subscribe to receive progress messages as\nthey are emitted by rsync, using the `:listener` option.\n\nErrors and unrecognized status lines are logged, and overall success or error\nis reported using the GenServer exit reason.\n\nBe extremely cautious when building source and target arguments, there is\nno built-in protection against filesystem traversal.  Use\n`Path.safe_relative/2` and the included `make_remote_path/3` according to your\nexpected needs.","ref":"Rsync.html"},{"type":"module","title":"Examples - Rsync","doc":"Push a file to the default user's home directory on a remote server:\n\n    Rsync.sync(\"local_file.txt\", \"host:\")\n\nRetrieve several remote files:\n\n    Rsync.sync(\n      Rsync.make_remote_paths(user, host, filenames),\n      \"local_path/\"\n    )\n\nSet up real-time monitoring of a transfer:\n\n    Rsync.sync(\"local_path\", \"host:remote_path\", listener: self())\n\n    receive do\n      {:progress, fraction_complete} ->\n        IO.puts(\"Transfer #{fraction_complete * 100}% complete\")\n\n      {:exit_status, 0} ->\n        IO.puts(\"Transfer successfully completed.\")\n    end\n\nKill a transfer:\n\n    {:ok, pid} = Rsync.sync(\"local\", \"remote\")\n\n    Rsync.stop(pid)\n\nHandle unsuccessful exit using a Supervisor or by trapping the linked signal:\n\n    Process.flag(:trap_exit, true)\n\n    Rsync.sync(\"source\", \"target\")\n\n    receive do\n      {:EXIT, _pid, {:error, exit_status}} ->\n        IO.puts(\"Failed with code: #{exit_status}\")\n    end","ref":"Rsync.html#module-examples"},{"type":"function","title":"Rsync.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Rsync.html#child_spec/1"},{"type":"function","title":"Rsync.get_progress/1","doc":"Return overall tranfer progress as a floating point number between 0 and 1.","ref":"Rsync.html#get_progress/1"},{"type":"function","title":"Rsync.make_remote_path/3","doc":"","ref":"Rsync.html#make_remote_path/3"},{"type":"function","title":"Rsync.make_remote_paths/3","doc":"","ref":"Rsync.html#make_remote_paths/3"},{"type":"type","title":"Rsync.option/0","doc":"","ref":"Rsync.html#t:option/0"},{"type":"type","title":"Rsync.options/0","doc":"","ref":"Rsync.html#t:options/0"},{"type":"function","title":"Rsync.start_link/2","doc":"","ref":"Rsync.html#start_link/2"},{"type":"function","title":"Rsync.stop/1","doc":"","ref":"Rsync.html#stop/1"},{"type":"function","title":"Rsync.sync/3","doc":"Start rsync file copy","ref":"Rsync.html#sync/3"},{"type":"function","title":"Options - Rsync.sync/3","doc":"* `:env` - Charlist tuples of environment variables to set.  For example,\n    `env: [{~c\"RSYNC_PARTIAL_DIR\", ~c\".rsync-partial\"}]`\n\n  * `:exe` - Path to the rsync executable.  Defaults to the first rsync in PATH.\n\n  * `:keyfile` - Path to ssh private identity.  Will be shell-expanded.\n    For example, `keyfile: \"~/.ssh/id_rsa-bot\"`\n\n  * `:listener` - Process which will listen for progress updates.  This process\n    may receive two message formats:\n\n      * `{:progress, float()}` - Fractional completion, such as 0.1 for 10%\n        overall progress.\n\n      * `{:exit_status, int()}` - Sent when the sync is finished, with an exit\n        status that should equal 0 on success.\n\n  * `:ssh_flags` - Commandline options to pass to ssh.  Will be\n    shell-expanded.  For example, `ssh_flags: \"-i ~/.ssh/id_rsa-bot -o StrictHostKeyChecking=no\"`\n\n  * `:source` - Source file or directory.  For multiple sources use `:sources`.\n\n  * `:sources` - List of source files or directories.  Follows the same rules\n    as rsync, where any directory name ending in \"/\" will be copied to the top\n    level without nesting under a directory on the target.  Remote sources\n    should each be prepended with user and hostname.\n\n  * `:target` - Target file or directory.  Remote target should be\n    prepended with user and hostname, for example `target: \"user@host:/path\"`.","ref":"Rsync.html#sync/3-options"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.1"}}